<?php

namespace App\Http\Controllers\Api\Event;

use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Traits\ResponseTrait;
use App\Interfaces\UserInterface;
use App\Interfaces\EventInterface;
use App\Http\Controllers\Controller;
use App\Http\Requests\Event\EventCreateRequest;

class EventController extends Controller
{
    use ResponseTrait;

    protected $event, $user;

    public function __construct(
        EventInterface $eventInterface,
        UserInterface $userInterface
        )
    {
        $this->event = $eventInterface;
        $this->user = $userInterface;
    }


    public function createEvent(EventCreateRequest $request)
    {
        $user=$this->user->getAuthUser($request);

        $data=[];
        $data['event_name']=$request->input('name');
        $data['event_date']=$request->input('date');
        $data['user_id']=$user->id;

        try{
            $event=$this->event->PostEvent($data);
            return $this->responseSuccess($event,'Event Created Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of function

    public function getEvents(Request $request)
    {
        $user=$this->user->getAuthUser($request);

        try{
            $userEvents=$this->event->getStudentEvents($user->id);
            return $this->responseSuccess($userEvents,'Event Fetched Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of function


    public function getEvent($id)
    {
        try{
            $editEvent=$this->event->getEventById($id);
            return $this->responseSuccess($editEvent,'Event Edit Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of function


    public function updateEvent(Request $request, $id)
    {
        $data=[];
        $data['event_name']=$request->input('name');
        $data['event_date']=$request->input('date');

       try{
        $updateEvent=$this->event->updateEvent($id,$data);
        return $this->responseSuccess($updateEvent,'Event Update Success',200);
       }catch(\Exception $e){
        return $this->responseError($e->getMessage(),'Error',401);
       }

    }//end of function

    public function deleteEvent($id)
    {
        try{
            $event=$this->event->EventDelete($id);
            return $this->responseSuccess($event,'Event Delete Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of function
}
