<?php

namespace App\Http\Controllers\Api\Goal;

use Illuminate\Http\Request;
use App\Traits\ResponseTrait;
use App\Interfaces\GoalInterface;
use App\Interfaces\UserInterface;
use App\Http\Controllers\Controller;
use App\Http\Requests\Goal\GoalCreateRequest;

class GoalController extends Controller
{
    use ResponseTrait;

    protected $goal, $user;

    public function __construct(
        GoalInterface $goalInterface,
        UserInterface $userInterface
        )
    {
        $this->goal = $goalInterface;
        $this->user = $userInterface;
    }


     public function createGoal(GoalCreateRequest $request)
    {
        $user=$this->user->getAuthUser($request);

        $data=[];
        $data['goal_name']=$request->input('goal');
        $data['user_id']=$user->id;

        try{
            $goal=$this->goal->PostGoal($data);
            return $this->responseSuccess($goal,'Goal Created Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }
    }//end of createGoal

    public function getGoals(Request $request)
    {
        $user=$this->user->getAuthUser($request);

        try{
            $userGoals=$this->goal->getStudentGoals($user->id);
            return $this->responseSuccess($userGoals,'Goal Fetched Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of getGoals

    public function getGoal($id)
    {
        try{
            $editGoal=$this->goal->getGoalById($id);
            return $this->responseSuccess($editGoal,'Note Edited Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of getGoal


    public function updateGoal(Request $request, $id)
    {

        $data=[];

        $data['goal_name']=$request->input('goal');

       try{
        $updateGoal=$this->goal->updateGoal($id,$data);
        return $this->responseSuccess($updateGoal,'Goal Update Success',200);
       }catch(\Exception $e){
        return $this->responseError($e->getMessage(),'Error',401);
       }

    }//end of updateGoal

    public function deleteGoal($id)
    {
        try{
            $goal=$this->goal->deleteGoal($id);
            return $this->responseSuccess($goal,'Goal Delete Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of deleteGoal

}
