<?php

namespace App\Http\Controllers\Api\Subscription;

use App\Models\Plan;
use Illuminate\Http\Request;
use App\Traits\ResponseTrait;
use App\Http\Controllers\Controller;
use App\Interfaces\SubscriptionInterface;
use App\Resolvers\PaymentPlatformResolver;

class PayPalSubscriptionController extends Controller
{
    use ResponseTrait;

    protected $paymentPlatformResolver, $sub;

    public function __construct(
        PaymentPlatformResolver $paymentPlatformResolver,
        SubscriptionInterface $subscriptionInterface
        )
    {
        $this->paymentPlatformResolver = $paymentPlatformResolver;
        $this->sub=$subscriptionInterface;
    }

    public function processSubscription(Request $request)
    {
        //get all data from frontend
        $data=[];

        $data['email']=$request->email;
        $data['first_name']=$request->first_name;
        $data['last_name']=$request->last_name;
        $data['password']=$request->password;
        $data['billing_address']=$request->billing_address;
        $data['card_number']=$request->card_number;
        $data['card_exp_date']=$request->card_exp_date;
        $data['card_cvc']=$request->card_cvc;
        $data['payment_platform']=$request->payment_platform;
        $data['plan']=$request->plan;


        $paymentPlatform=$this->paymentPlatformResolver->resolveService($request->payment_platform);
        session()->put('subscriptionPlatformId',$request->payment_platform);

        return $paymentPlatform->handleSubscription($request);

    }//end of processSubscription

    public function approvalSubscription(Request $request)
    {
        try{
            $plan=Plan::where('slug',$request->plan)->firstOrFail();
            $user=$request->user();
            $paymentPlatform=$this->paymentPlatformResolver->resolveService(1);
            $subscriptionDetails=$paymentPlatform->subscriptionDetails($request->subscriptionId);

            if($subscriptionDetails->status ==="ACTIVE" && $request->plan!==null){

                if($this->sub->NotExistingSubscriberId($request->subscriptionId)){

                    $data=[];
                    $data['subscription_id']=$request->subscriptionId;
                    $data['active_until']=now()->addDays($plan->duration_in_days);
                    $data['payment_method']=null;
                    $data['email']=auth()->user()->email;
                    $data['user_id']=$user->id;
                    $data['plan_id']=$plan->id;
                    $data['payment_platform_id']=1;

                    try{
                        $subscription=$this->sub->CreateSubscription($data);
                        return $this->responseSuccess($subscription,'Subscription active successfully', 200);

                    }catch(\Exception $e){
                        return $this->responseError($e->getMessage(), 'Subscription activation failed', 400);
                    }
                }
            }

            if($subscriptionDetails->status ==="ACTIVE" && $request->plan!==null){
                return $this->responseSuccess($subscriptionDetails,'Subscription active successfully', 200);
            }
            // return $this->responseError($subscriptionDetails, 'Subscription not active try again', 400);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(), 'Subscription activation failed', 400);
        }

    }//end of processSubscription

    public function canceledSubscription()
    {

    }//end of canceledSubscription


    public function subscriptionDetails($subscriptionId)
    {

    }//end of subscriptionDetails






}
