<?php

namespace App\Http\Controllers\Api\Word;

use Illuminate\Http\Request;
use App\Traits\ResponseTrait;
use App\Interfaces\UserInterface;
use App\Interfaces\WordInterface;
use App\Http\Controllers\Controller;
use App\Http\Requests\Word\CreateWordRequest;

class WordController extends Controller
{
    use ResponseTrait;

    protected $word, $user;

    
    public function __construct(
        WordInterface $wordInterface,
        UserInterface $userInterface
    ) {
        $this->word = $wordInterface;
        $this->user = $userInterface;
    }

    
    public function createWord(CreateWordRequest $request)
    {
        $user = $this->user->getAuthUser($request);
        $data = [];

        $data['word_content'] = $request->input('content');
        $data['user_id'] = $user->id;

        try {
            $word = $this->word->PostWord($data);
            return $this->responseSuccess($word, 'Note Created Success', 200);
        } catch (\Exception $e) {
            return $this->responseError($e->getMessage(), 'Error', 401);
        }
    } //end createWord

    public function getWords(Request $request)
    {
        $user = $this->user->getAuthUser($request);

        try {
            $wordContents = $this->word->getStudentWords($user->id);
            return $this->responseSuccess(
                $wordContents,
                'Word Created Success',
                200
            );
        } catch (\Exception $e) {
            return $this->responseError($e->getMessage(), 'Error', 401);
        }
    } //end getWords

    public function getWord($id)
    {
        try {
            $editWord = $this->word->getWordById($id);
            return $this->responseSuccess(
                $editWord,
                'Word Update Success',
                200
            );
        } catch (\Exception $e) {
            return $this->responseError($e->getMessage(), 'Error', 401);
        }
    } //end getWord

    public function updateWord(Request $request, $id)
    {

        $data = [];

        $data['word_content'] = $request->input('content');

        try {
            $updateWord = $this->word->updateWord($id, $data);
            return $this->responseSuccess(
                $updateWord,
                'Word Update Success',
                200
            );
        } catch (\Exception $e) {
            return $this->responseError($e->getMessage(), 'Error', 401);
        }
    } //end updateWord

    public function deleteWord($id)
    {
        try {
            $word = $this->word->deleteWord($id);
            return $this->responseSuccess($word, 'Word Delete Success', 200);
        } catch (\Exception $e) {
            return $this->responseError($e->getMessage(), 'Error', 401);
        }
    } //end deleteWord

}
