<?php

namespace App\Models;

use App\Models\Goal;
use App\Models\Note;
use App\Models\Word;
use App\Models\Event;
use App\Models\Network;
use App\Models\Subscription;
use Laravel\Sanctum\HasApiTokens;
use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use HasFactory, Notifiable, HasApiTokens;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'phone_number',
        'dob',
        'referral_code',
        'referral_link',
        'question1',
        'question2',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed',
        ];
    }


    public function subscription()
    {
        return $this->hasOne(Subscription::class);
    }

    public function hasActiveSubscription()
    {
        return optional($this->subscription->isActive() ?? false);
    }
    public function networks()
    {
        return $this->hasMany(Network::class);
    }

    public function notes()
    {
        return $this->hasMany(Note::class);
    }
    public function events()
    {
        return $this->hasMany(Event::class);
    }
    public function goals()
    {
        return $this->hasMany(Goal::class);
    }
    public function words()
    {
        return $this->hasMany(Word::class);
    }

}
