<?php

namespace App\Services;

use App\Traits\ConsumesExternalServices;
use App\Traits\ResponseTrait;
use Illuminate\Http\Request;


class StripeService
{
    use ConsumesExternalServices, ResponseTrait;

    protected $baseUri;

    protected $clientId;

    protected $clientSecret;

    protected $plans;

    public function __construct()
    {
        $this->baseUri = config('services.stripe.base_uri');
        $this->clientId = config('services.stripe.key');
        $this->clientSecret = config('services.stripe.secret');
        $this->plans = config('services.stripe.plans');
    }


    public function resolveAuthorization(&$queryParams, &$formParams, &$headers)
    {
        $headers['Authorization'] = $this->resolveAccessToken();
    }

    public function decodeResponse($response)
    {
        return json_decode($response);
    }

    public function resolveAccessToken()
    {
        return "Bearer {$this->clientSecret}";
    }


    public function handleSubscription($request)
    {
        //create a new customer
        $customer = $this->createCustomer(
            $request->user()->name,
            $request->user()->email,
            $request->payment_method
        );
        try {
            //create a subscription for the customer
            $subscription = $this->createSubscription(
                $customer->id,
                $request->payment_method,
                $this->plans[$request->plan]
            );

            if ($subscription->status == 'active') {
                session()->put('subscriptionId', $subscription->id);
                return $this->responseSuccess($subscription, 'Subscription Created Successfully', 200);
            }
        } catch (\Exception $e) {
            return $this->responseError($e->getMessage(), 'Error', 401);
        }
    }


    public function createCustomer($name, $email, $paymentMethod)
    {
        return $this->makeRequest(
            'POST',
            '/v1/customers',
            [],
            [
                'name' => $name,
                'email' => $email,
                'payment_method' => $paymentMethod
            ]
        );
    }


    public function createSubscription($customerId, $paymentMethod, $priceId)
    {
        return $this->makeRequest(
            'POST',
            '/v1/subscriptions',
            [
                //request-form-params
            ],
            [
                //request-body-params
                'customer' => $customerId,
                'items' => [
                    ['price' => $priceId]
                ],
                'default_payment_method' => $paymentMethod
            ],
            // [
                //request-header-config
            // ],
            // $isJsonRequest = true
        );
    } //end of method

    public function subscriptionDetails($subscriptionId)
    {
        return $this->makeRequest(
            'GET',
            "/v1/subscriptions/{$subscriptionId}",
            [
                //request-form-params
            ],
            [
                //request-body-params
            ],
            [
                //request-headers-config
                'Content-type' => 'application/json'
            ]
        );
    }
}
